#
# spec file for package libksieve
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang

Name:           libksieve
Version:        17.04.2
Release:        1.1
%define kf5_version 5.26.0
# Latest stable Applications (e.g. 16.08 in KA, but 16.11.80 in KUA)
%{!?_kapp_version: %global _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
Summary:        Sieve and Managesieve support library for KDE PIM
License:        GPL-2.0 and LGPL-2.1+
Group:          Development/Libraries/KDE
Url:            http://www.kde.org
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cyrus-sasl-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  karchive-devel
BuildRequires:  kdoctools-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kidentitymanagement-devel >= %{_kapp_version}
BuildRequires:  kio-devel
BuildRequires:  kmailtransport-devel >= %{_kapp_version}
BuildRequires:  kmime-devel
BuildRequires:  knewstuff-devel
BuildRequires:  kpimtextedit-devel
BuildRequires:  kwindowsystem-devel
BuildRequires:  libkdepim-devel
BuildRequires:  pimcommon-devel >= %{_kapp_version}
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5SyntaxHighlighting)
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.6.0
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.6.0
BuildRequires:  pkgconfig(Qt5WebEngineWidgets) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Xml) >= 5.6.0
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %ix86 x86_64 %arm aarch64 mips mips64
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains the libksieve library, which is used to support
the Sieve server-side mail filtering protocol in KDE PIM applications.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %kf5_find_htmldocs
%endif

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%package devel
Summary:        Development package for libksieve
# FIXME: use correct group, see "https://en.opensuse.org/openSUSE:Package_group_guidelines"
License:        LGPL-2.1+
Group:          Development/Libraries/KDE
Requires:       libksieve = %{version}

%description devel
This package contains development headers of libksieve.

%files devel
%defattr(-,root,root)
%{_includedir}/KF5/KManageSieve/
%{_includedir}/KF5/KSieveUi/
%{_includedir}/KF5/kmanagesieve/
%{_includedir}/KF5/ksieveui/
%{_includedir}/KF5/libksieve_version.h
%{_libdir}/cmake/KF5LibKSieve/
%{_libdir}/qt5/mkspecs/modules/qt_KManageSieve.pri
%{_libdir}/qt5/mkspecs/modules/qt_KSieve.pri
%{_libdir}/qt5/mkspecs/modules/qt_KSieveUi.pri
%{_libdir}/libKF5KManageSieve.so
%{_libdir}/libKF5KSieve.so
%{_libdir}/libKF5KSieveUi.so

%files
%defattr(-,root,root)
%{_kf5_configdir}/ksieve_script.knsrc
%config %{_kf5_configdir}/libksieve.categories
%config %{_kf5_configdir}/libksieve.renamecategories
%{_datadir}/sieve/
%{_libdir}/libKF5KManageSieve.so.*
%{_libdir}/libKF5KSieve.so.*
%{_libdir}/libKF5KSieveUi.so.*
%{_kf5_plugindir}/kf5/kio/sieve.so
%{_kf5_htmldir}/en/kioslave5/
%{_kf5_servicesdir}/sieve.protocol

%if %{with lang}
%files lang -f %{name}.lang
%doc COPYING*
%endif

%changelog
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Fix order of attributes
  * Add newline after each error message
  * Don't add empty requires
  * Don't double quote when we have a list
  * Fix generate body element when we have a list
  * Body supports list too
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * increase version
* Sun Mar 26 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Feb  4 2017 jengelh@inai.de
- RPM group specialization
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Mon Dec 12 2016 lbeltrame@kde.org
- Update description
* Sat Dec  3 2016 wbauer@tmo.at
- Cleanup/update build requirements
- Remove obsolete -DQTWEBENGINE_SUPPORT_OPTION cmake option,
  QtWebEngine is mandatory now
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Tue Aug 23 2016 fabian@ritter-vogt.de
- Build only on architectures supported by libqt5-qtwebengine
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Thu Jul 21 2016 wbauer@tmo.at
- Cleanup build requirements
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
